diff src/gui_w32.c @ 27922:b4ef8f851be4 v8.2.4486

patch 8.2.4486: MS-Windows GUI: slow scrolling with maximized window Commit: https://github.com/vim/vim/commit/f01af9c4e6f1438cd1112cfff42f3837028c7846 Author: Bram Moolenaar <Bram@vim.org> Date: Tue Mar 1 16:02:26 2022 +0000 patch 8.2.4486: MS-Windows GUI: slow scrolling with maximized window Problem: MS-Windows GUI: slow scrolling with maximized window. Solution: Use a better way to check the window is on screen. (Ken Takata, closes #9865)
author Bram Moolenaar <Bram@vim.org>
date Tue, 01 Mar 2022 17:15:03 +0100
parents 2be33ea63428
children 29b30e2376fe
line wrap: on
line diff
--- a/src/gui_w32.c
+++ b/src/gui_w32.c
@@ -3016,7 +3016,7 @@ is_point_onscreen(int x, int y)
 }
 
 /*
  * Check if the whole area of the specified window is on-screen.
  *
  * Note about DirectX: Windows 10 1809 or above no longer maintains image of
  * the window portion that is off-screen.  Scrolling by DWriteContext_Scroll()
@@ -3026,16 +3026,23 @@ is_point_onscreen(int x, int y)
 is_window_onscreen(HWND hwnd)
 {
     RECT    rc;
-
-    GetWindowRect(hwnd, &rc);
-
-    if (!is_point_onscreen(rc.left, rc.top))
+    POINT   p1, p2;
+
+    GetClientRect(hwnd, &rc);
+    p1.x = rc.left;
+    p1.y = rc.top;
+    p2.x = rc.right - 1;
+    p2.y = rc.bottom - 1;
+    ClientToScreen(hwnd, &p1);
+    ClientToScreen(hwnd, &p2);
+
+    if (!is_point_onscreen(p1.x, p1.y))
 	return FALSE;
-    if (!is_point_onscreen(rc.left, rc.bottom))
+    if (!is_point_onscreen(p1.x, p2.y))
 	return FALSE;
-    if (!is_point_onscreen(rc.right, rc.top))
+    if (!is_point_onscreen(p2.x, p1.y))
 	return FALSE;
-    if (!is_point_onscreen(rc.right, rc.bottom))
+    if (!is_point_onscreen(p2.x, p2.y))
 	return FALSE;
     return TRUE;
 }
@@ -3016,7 +3016,7 @@ is_point_onscreen(int x, int y)
 
 /*
- * Check if the whole area of the specified window is on-screen.
+ * Check if the whole client area of the specified window is on-screen.
  *
  * Note about DirectX: Windows 10 1809 or above no longer maintains image of